:mod:`euphorie.content.countrymanager`
======================================

.. module:: euphorie.content.countrymanager

.. autointerface:: ICountryManager

Account support
---------------

.. autoclass:: CountryManagerLocalRoleProvider
   :members:

Views
-----

.. autoclass:: View

